@@ -1,7 +1,7 @@
 # Human friendly input/output in Python.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: February 16, 2020
+# Last Change: March 1, 2020
 # URL: https://humanfriendly.readthedocs.io
 
 """
@@ -17,8 +17,8 @@ code that is compatible with Python 2 and Python 3.
 
 .. data:: HTMLParser
 
-   Alias for :func:`python2:HTMLParser.HTMLParser` (in Python 2) or
-   :func:`python3:html.parser.HTMLParser` (in Python 3).
+   Alias for :class:`python2:HTMLParser.HTMLParser` (in Python 2) or
+   :class:`python3:html.parser.HTMLParser` (in Python 3).
 
 .. data:: interactive_prompt
 
@@ -39,7 +39,7 @@ code that is compatible with Python 2 and Python 3.
 
    Alias for :func:`python3:time.monotonic()` (in Python 3.3 and higher) or
    `monotonic.monotonic()` (a `conditional dependency
-   <https://pypi.python.org/pypi/monotonic/>`_ on older Python versions).
+   <https://pypi.org/project/monotonic/>`_ on older Python versions).
 """
 
 __all__ = (
@@ -52,15 +52,18 @@ __all__ = (
     'is_unicode',
     'monotonic',
     'name2codepoint',
+    'on_windows',
     'unichr',
     'unicode',
     # This export remains here so as not to break my dozen or so other Python
     # projects using 'from humanfriendly.compat import unittest' from good old
     # times (when Python 2.6 was still a thing). It will eventually be removed.
     'unittest',
+    'which',
 )
 
 # Standard library modules.
+import sys
 import unittest
 
 # Differences between Python 2 and 3.
@@ -70,6 +73,7 @@ try:
     unichr = unichr
     basestring = basestring
     interactive_prompt = raw_input
+    from distutils.spawn import find_executable as which
     from HTMLParser import HTMLParser
     from StringIO import StringIO
     from htmlentitydefs import name2codepoint
@@ -79,6 +83,7 @@ except (ImportError, NameError):
     unichr = chr
     basestring = str
     interactive_prompt = input
+    from shutil import which
     from html.parser import HTMLParser
     from io import StringIO
     from html.entities import name2codepoint
@@ -88,7 +93,7 @@ try:
     from time import monotonic
 except ImportError:
     # A replacement for older Python versions:
-    # https://pypi.python.org/pypi/monotonic/
+    # https://pypi.org/project/monotonic/
     try:
         from monotonic import monotonic
     except (ImportError, RuntimeError):
@@ -125,3 +130,12 @@ def is_unicode(value):
     :returns: :data:`True` if the value is a Unicode string, :data:`False` otherwise.
     """
     return isinstance(value, unicode)
+
+
+def on_windows():
+    """
+    Check if we're running on the Microsoft Windows OS.
+
+    :returns: :data:`True` if running Windows, :data:`False` otherwise.
+    """
+    return sys.platform.startswith('win')
